@@ -53,7 +53,10 @@ impl Preprocessor for Backlinks {
             if let BookItem::Chapter(ch) = item {
                 if let Some(source_path) = &ch.source_path {
                     if let Some(backlinks) = index.get(source_path) {
-                        ch.content += &backlink_prefix;
+                        if backlinks.len() >= 1 {
+                            ch.content += &backlink_prefix;
+                        };
+
                         for backlink in backlinks.iter() {
                             // This is really ugly, but the unwraps should be safe
                             let dest = backlink.source_path.clone().unwrap();
